==> jc-1.4.0.tar.gz: java/util/prefs/NodeChangeEvent.h <==
// public class java.util.prefs.NodeChangeEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class d42d0fdac79fabc0 java_util_prefs_NodeChangeEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_util_prefs_NodeChangeEvent_H_
#define _JC_java_util_prefs_NodeChangeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_java_util_prefs_NodeChangeEvent$sub_refs	_jc_java_util_prefs_NodeChangeEvent$sub_refs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$sub_nonrefs	_jc_java_util_prefs_NodeChangeEvent$sub_nonrefs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$refs	_jc_java_util_prefs_NodeChangeEvent$refs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$nonrefs	_jc_java_util_prefs_NodeChangeEvent$nonrefs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$object	_jc_java_util_prefs_NodeChangeEvent$object;

typedef struct _jc_java_util_prefs_NodeChangeEvent$fields_struct	_jc_java_util_prefs_NodeChangeEvent$fields_struct;
typedef const struct _jc_java_util_prefs_NodeChangeEvent$vmethods	_jc_java_util_prefs_NodeChangeEvent$vmethods;
typedef const struct _jc_java_util_prefs_NodeChangeEvent$vtable	_jc_java_util_prefs_NodeChangeEvent$vtable;
typedef const struct _jc_java_util_prefs_NodeChangeEvent$vtype	_jc_java_util_prefs_NodeChangeEvent$vtype;

// Class fields structure
struct _jc_java_util_prefs_NodeChangeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_NodeChangeEvent$fields_struct _jc_java_util_prefs_NodeChangeEvent$class_fields;

// Constructors
extern void _jc_java_util_prefs_NodeChangeEvent$method$_init$1663b1e823f206aa(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *, struct _jc_java_util_prefs_Preferences$object *, struct _jc_java_util_prefs_Preferences$object *);

// Virtual methods
extern struct _jc_java_util_prefs_Preferences$object *_jc_java_util_prefs_NodeChangeEvent$method$getChild$075de7452c771972(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *);
extern struct _jc_java_util_prefs_Preferences$object *_jc_java_util_prefs_NodeChangeEvent$method$getParent$3f4ad1da1e315696(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_NodeChangeEvent$method_info$getChild$075de7452c771972;
extern _jc_method _jc_java_util_prefs_NodeChangeEvent$method_info$getParent$3f4ad1da1e315696;

// Virtual methods structure
struct _jc_java_util_prefs_NodeChangeEvent$vmethods {
	struct _jc_java_util_prefs_Preferences$object	*(*getChild$075de7452c771972)(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *);
	struct _jc_java_util_prefs_Preferences$object	*(*getParent$3f4ad1da1e315696)(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *);
};

// Vtable
struct _jc_java_util_prefs_NodeChangeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_util_prefs_NodeChangeEvent$vmethods	java_util_prefs_NodeChangeEvent;
};

// Vtype
struct _jc_java_util_prefs_NodeChangeEvent$vtype {
	_jc_type			type;
	_jc_java_util_prefs_NodeChangeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_NodeChangeEvent$sub_refs {
	struct _jc_java_util_prefs_Preferences$object	*child;
};

// Reference instance fields (object)
struct _jc_java_util_prefs_NodeChangeEvent$refs {
    _jc_java_util_prefs_NodeChangeEvent$sub_refs	java_util_prefs_NodeChangeEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_NodeChangeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_NodeChangeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_util_prefs_NodeChangeEvent$sub_nonrefs	java_util_prefs_NodeChangeEvent;
};

// Object instance structure
struct _jc_java_util_prefs_NodeChangeEvent$object {
	_jc_java_util_prefs_NodeChangeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_NodeChangeEvent$vtype	*vtype;
	_jc_java_util_prefs_NodeChangeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_NodeChangeEvent$vtype _jc_java_util_prefs_NodeChangeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_NodeChangeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_NodeChangeEvent$class_object;

#endif	/* _JC_java_util_prefs_NodeChangeEvent_H_ */

==> jc-1.4.6.tar.gz: java/util/prefs/NodeChangeEvent.h <==
// public class java.util.prefs.NodeChangeEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class d42d0fdac79fabc0 java_util_prefs_NodeChangeEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_util_prefs_NodeChangeEvent_H_
#define _JC_java_util_prefs_NodeChangeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_java_util_prefs_NodeChangeEvent$sub_refs	_jc_java_util_prefs_NodeChangeEvent$sub_refs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$sub_nonrefs	_jc_java_util_prefs_NodeChangeEvent$sub_nonrefs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$refs	_jc_java_util_prefs_NodeChangeEvent$refs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$nonrefs	_jc_java_util_prefs_NodeChangeEvent$nonrefs;
typedef struct _jc_java_util_prefs_NodeChangeEvent$object	_jc_java_util_prefs_NodeChangeEvent$object;

typedef struct _jc_java_util_prefs_NodeChangeEvent$fields_struct	_jc_java_util_prefs_NodeChangeEvent$fields_struct;
typedef const struct _jc_java_util_prefs_NodeChangeEvent$vmethods	_jc_java_util_prefs_NodeChangeEvent$vmethods;
typedef const struct _jc_java_util_prefs_NodeChangeEvent$vtable	_jc_java_util_prefs_NodeChangeEvent$vtable;
typedef const struct _jc_java_util_prefs_NodeChangeEvent$vtype	_jc_java_util_prefs_NodeChangeEvent$vtype;

// Class fields structure
struct _jc_java_util_prefs_NodeChangeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_NodeChangeEvent$fields_struct _jc_java_util_prefs_NodeChangeEvent$class_fields;

// Constructors
extern void _jc_java_util_prefs_NodeChangeEvent$method$_init$1663b1e823f206aa(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *, struct _jc_java_util_prefs_Preferences$object *, struct _jc_java_util_prefs_Preferences$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_prefs_Preferences$object *_jc_java_util_prefs_NodeChangeEvent$method$getChild$075de7452c771972(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_prefs_Preferences$object *_jc_java_util_prefs_NodeChangeEvent$method$getParent$3f4ad1da1e315696(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_NodeChangeEvent$method_info$getChild$075de7452c771972;
extern _jc_method _jc_java_util_prefs_NodeChangeEvent$method_info$getParent$3f4ad1da1e315696;

// Virtual methods structure
struct _jc_java_util_prefs_NodeChangeEvent$vmethods {
	struct _jc_java_util_prefs_Preferences$object	*(*getChild$075de7452c771972)(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_prefs_Preferences$object	*(*getParent$3f4ad1da1e315696)(_jc_env *, struct _jc_java_util_prefs_NodeChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_prefs_NodeChangeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_util_prefs_NodeChangeEvent$vmethods	java_util_prefs_NodeChangeEvent;
};

// Vtype
struct _jc_java_util_prefs_NodeChangeEvent$vtype {
	_jc_type			type;
	_jc_java_util_prefs_NodeChangeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_NodeChangeEvent$sub_refs {
	struct _jc_java_util_prefs_Preferences$object	*child;
};

// Reference instance fields (object)
struct _jc_java_util_prefs_NodeChangeEvent$refs {
    _jc_java_util_prefs_NodeChangeEvent$sub_refs	java_util_prefs_NodeChangeEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_NodeChangeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_NodeChangeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_util_prefs_NodeChangeEvent$sub_nonrefs	java_util_prefs_NodeChangeEvent;
};

// Object instance structure
struct _jc_java_util_prefs_NodeChangeEvent$object {
	_jc_java_util_prefs_NodeChangeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_NodeChangeEvent$vtype	*vtype;
	_jc_java_util_prefs_NodeChangeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_NodeChangeEvent$vtype _jc_java_util_prefs_NodeChangeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_NodeChangeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_NodeChangeEvent$class_object;

#endif	/* _JC_java_util_prefs_NodeChangeEvent_H_ */
